==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2beta1PodsMetricStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V2beta1PodsMetricStatusFluent<A extends V2beta1PodsMetricStatusFluent<A>> extends Fluent<A>{


    public String getCurrentAverageValue();
    public A withCurrentAverageValue(String currentAverageValue);
    public Boolean hasCurrentAverageValue();
    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getSelector();
    public V1LabelSelector buildSelector();
    public A withSelector(V1LabelSelector selector);
    public Boolean hasSelector();
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> withNewSelector();
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> withNewSelectorLike(V1LabelSelector item);
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> editSelector();
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> editOrNewSelector();
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> editOrNewSelectorLike(V1LabelSelector item);

    public interface SelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1PodsMetricStatusFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1PodsMetricStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V2beta1PodsMetricStatusFluent<A extends V2beta1PodsMetricStatusFluent<A>> extends Fluent<A>{


    public String getCurrentAverageValue();
    public A withCurrentAverageValue(String currentAverageValue);
    public Boolean hasCurrentAverageValue();
    public A withNewCurrentAverageValue(String arg1);
    public A withNewCurrentAverageValue(StringBuilder arg1);
    public A withNewCurrentAverageValue(StringBuffer arg1);
    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    public A withNewMetricName(String arg1);
    public A withNewMetricName(StringBuilder arg1);
    public A withNewMetricName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getSelector();
    public V1LabelSelector buildSelector();
    public A withSelector(V1LabelSelector selector);
    public Boolean hasSelector();
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> withNewSelector();
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> withNewSelectorLike(V1LabelSelector item);
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> editSelector();
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> editOrNewSelector();
    public V2beta1PodsMetricStatusFluent.SelectorNested<A> editOrNewSelectorLike(V1LabelSelector item);

    public interface SelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1PodsMetricStatusFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}


}
